//original code can be found at: https://create.arduino.cc/projecthub/Oniichan_is_ded/neopixel-x-arduino-x-button-c26e9a
#include <Adafruit_NeoPixel.h>

#define BUTTON_PIN   2    
#define PIXEL_PIN    6    // Digital IO pin connected to the NeoPixels.

#define PIXEL_COUNT 7


Adafruit_NeoPixel strip = Adafruit_NeoPixel(PIXEL_COUNT, PIXEL_PIN, NEO_GRB + NEO_KHZ800);

bool oldState = HIGH;
int showType = 0;

void setup() {
  pinMode(BUTTON_PIN, INPUT_PULLUP);
  strip.begin();
  strip.show(); // Initialize all pixels to 'off'
}

void loop() {
  // Get current button state.
  bool newState = digitalRead(BUTTON_PIN);

  // Check if state changed from high to low (button press).
  if (newState == LOW && oldState == HIGH) {
    // Short delay to debounce button.
    delay(20);
    // Check if button is still low after debounce.
    newState = digitalRead(BUTTON_PIN);
    if (newState == LOW) {
      showType++;
      if (showType > 16)
        showType=0;
      startShow(showType);
    }
  }

  // Set the last button state to the old state.
  oldState = newState;
}

void startShow(int i) {
  switch(i){
    case 0: colorWipe(strip.Color(0, 0, 0), 100);    // Black/off
            break;
    case 1: colorWipe(strip.Color(255, 0, 0), 100);  // Red
            break;
    case 2: colorWipe(strip.Color(0, 0, 0), 100);    // Black/off
            break;        
    case 3: colorWipe(strip.Color(0, 255, 0), 100);  // Green
            break;
    case 4: colorWipe(strip.Color(0, 0, 0), 100);    // Black/off
            break; 
    case 5: colorWipe(strip.Color(0, 0, 255), 100);  // Blue
            break;
    case 6: colorWipe(strip.Color(0, 0, 0), 100);    // Black/off
            break; 
    case 7: colorWipe(strip.Color(157, 0, 255), 100); // Purple
            break;
    case 8: colorWipe(strip.Color(0, 0, 0), 100);    // Black/off
            break; 
    case 9: colorWipe(strip.Color(3,   252,   244), 100); // Blue
            break;
    case 10: colorWipe(strip.Color(0, 0, 0), 100);    // Black/off
            break; 
    case 11: colorWipe(strip.Color(  252,   248, 3), 100); // Yellow
            break;
    case 12: colorWipe(strip.Color(0, 0, 0), 100);    // Black/off
            break; 
    case 13: rainbow(200);
            break;
    case 14: colorWipe(strip.Color(0, 0, 0), 100);    // Black/off
            break;        
    case 15: rainbowCycle(20);
            break;
    case 16: colorWipe(strip.Color(0, 0, 0), 50);    // Black/off
            break; 
            

  }
}

// Fill the dots one after the other with a color
void colorWipe(uint32_t c, uint8_t wait) {
  for(uint16_t i=0; i<strip.numPixels(); i++) {
    strip.setPixelColor(i, c);
    strip.show();
    delay(wait);
  }
}

void rainbow(uint8_t wait) {
  uint16_t i, j;

  for(j=0; j<256; j++) {
    for(i=0; i<strip.numPixels(); i++) {
      strip.setPixelColor(i, Wheel((i+j) & 255));
    }
    strip.show();
    delay(wait);
  }
}

// Slightly different, this makes the rainbow equally distributed throughout
void rainbowCycle(uint8_t wait) {
  uint16_t i, j;

  for(j=0; j<256*5; j++) { // 5 cycles of all colors on wheel
    for(i=0; i< strip.numPixels(); i++) {
      strip.setPixelColor(i, Wheel(((i * 256 / strip.numPixels()) + j) & 255));
    }
    strip.show();
    delay(wait);
  }
}

//Theatre-style crawling lights.
void theaterChase(uint32_t c, uint8_t wait) {
  for (int j=0; j<10; j++) {  //do 10 cycles of chasing
    for (int q=0; q < 3; q++) {
      for (int i=0; i < strip.numPixels(); i=i+3) {
        strip.setPixelColor(i+q, c);    //turn every third pixel on
      }
      strip.show();

      delay(wait);

      for (int i=0; i < strip.numPixels(); i=i+3) {
        strip.setPixelColor(i+q, 0);        //turn every third pixel off
      }
    }
  }
}

//Theatre-style crawling lights with rainbow effect
void theaterChaseRainbow(uint8_t wait) {
  for (int j=0; j < 256; j++) {     // cycle all 256 colors in the wheel
    for (int q=0; q < 3; q++) {
      for (int i=0; i < strip.numPixels(); i=i+3) {
        strip.setPixelColor(i+q, Wheel( (i+j) % 255));    //turn every third pixel on
      }
      strip.show();

      delay(wait);

      for (int i=0; i < strip.numPixels(); i=i+3) {
        strip.setPixelColor(i+q, 0);        //turn every third pixel off
      }
    }
  }
}

// Input a value 0 to 255 to get a color value.
// The colours are a transition r - g - b - back to r.
uint32_t Wheel(byte WheelPos) {
  WheelPos = 255 - WheelPos;
  if(WheelPos < 85) {
    return strip.Color(255 - WheelPos * 3, 0, WheelPos * 3);
  }
  if(WheelPos < 170) {
    WheelPos -= 85;
    return strip.Color(0, WheelPos * 3, 255 - WheelPos * 3);
  }
  WheelPos -= 170;
  return strip.Color(WheelPos * 3, 255 - WheelPos * 3, 0);
}
